function tplot2(m,n0,n1,n2,fx)
% tplot2: plots thermodynamic property data
% function tplot2(m,n0,n1,n2,fx)
% Turns the plot hold ON.
% Plots column n2 vs column n1 in m with lines of constant
%    column n0 connected by dotted line.
%      Argument List
% Arg   Specifies
%  m   matrix of data from thermo properties FORTRAN program.
%  n0  column with data to sort on: 1 is p, 2 is t
%  n1  column of data for x axis
%  n2  column of data for y axis
%  fx  fraction to shift text message to the left.
%      If it is not given, 0.05 is used for fx.
%       Values of nk
%  k    Specifies
%  1   Pressure kPa
%  2   Temperature C
%  3   Volume m3/kg
%  4   Entropy kJ/kg-K
%  5   Enthalpy kJ/kg
%  6   Int. Eng. kJ/kg
disp('Please use tplot3')
